@@ -3,7 +3,7 @@ use strict;
 use warnings;
 use Cwd;
 
-our $VERSION = '0.9010';
+our $VERSION = '0.9020';
 
 sub new {
     my($class, $file) = @_;
@@ -18,6 +18,13 @@ sub load {
     $self;
 }
 
+sub save {
+    my($self, $path) = @_;
+
+    open my $out, ">", $path or die "$path: $!";
+    print {$out} $self->to_string;
+}
+
 sub parse {
     my $self = shift;
 
@@ -25,6 +32,15 @@ sub parse {
     $self->{result} = Module::CPANfile::Environment::parse($file) or die $@;
 }
 
+sub from_prereqs {
+    my($proto, $prereqs) = @_;
+
+    my $self = $proto->new;
+    $self->{result} = Module::CPANfile::Result->from_prereqs($prereqs);
+
+    $self;
+}
+
 sub prereqs { shift->prereq }
 
 sub prereq {
@@ -54,6 +70,37 @@ sub merge_meta {
     CPAN::Meta->new($struct)->save($file, { version => $version });
 }
 
+sub to_string {
+    my($self, $include_empty) = @_;
+
+    my $prereqs = $self->{result}{spec};
+
+    my $code = '';
+    for my $phase (qw(runtime configure build test develop)) {
+        my $indent = $phase eq 'runtime' ? '' : '    ';
+
+        my($phase_code, $requirements);
+        $phase_code .= "on $phase => sub {\n" unless $phase eq 'runtime';
+
+        for my $type (qw(requires recommends suggests conflicts)) {
+            for my $mod (sort keys %{$prereqs->{$phase}{$type}}) {
+                my $ver = $prereqs->{$phase}{$type}{$mod};
+                $phase_code .= $ver eq '0'
+                             ? "${indent}$type '$mod';\n"
+                             : "${indent}$type '$mod', '$ver';\n";
+                $requirements++;
+            }
+        }
+
+        $phase_code .= "};\n" unless $phase eq 'runtime';
+
+        $code .= $phase_code . "\n" if $requirements or $include_empty;
+    }
+
+    $code =~ s/\n+$/\n/s;
+    $code;
+}
+
 package Module::CPANfile::Environment;
 use strict;
 
@@ -109,6 +156,14 @@ EVAL
 package Module::CPANfile::Result;
 use strict;
 
+sub from_prereqs {
+    my($class, $spec) = @_;
+    bless {
+        phase => 'runtime',
+        spec => $spec,
+    }, $class;
+}
+
 sub new {
     bless {
         phase => 'runtime', # default phase
@@ -203,6 +258,25 @@ specific dependencies, not just for CPAN distributions.
 Load and parse a cpanfile. By default it tries to load C<cpanfile> in
 the current directory, unless you pass the path to its argument.
 
+=item from_prereqs
+
+  $file = Module::CPANfile->from_prereqs({
+    runtime => { requires => { DBI => '1.000' } },
+  });
+
+Creates a new Module::CPANfile object from prereqs hash you can get
+via L<CPAN::Meta>'s C<prereqs>, or L<CPAN::Meta::Prereqs>'
+C<as_string_hash>.
+
+  # read MYMETA, then feed the prereqs to create Module::CPANfile
+  my $meta = CPAN::Meta->load_file('MYMETA.json');
+  my $file = Module::CPANfile->from_prereqs($meta->prereqs);
+
+  # load cpanfile, then recreate it with round-trip
+  my $file = Module::CPANfile->load('cpanfile');
+  $file = Module::CPANfile->from_prereqs($file->prereq_specs);
+                                    # or $file->prereqs->as_string_hash
+
 =item prereqs
 
 Returns L<CPAN::Meta::Prereqs> object out of the parsed cpanfile.
@@ -211,6 +285,37 @@ Returns L<CPAN::Meta::Prereqs> object out of the parsed cpanfile.
 
 Returns a hash reference that should be passed to C<< CPAN::Meta::Prereqs->new >>.
 
+=item to_string($include_empty)
+
+  $file->to_string;
+  $file->to_string(1);
+
+Returns a canonical string (code) representation for cpanfile. Useful
+if you want to convert L<CPAN::Meta::Prereqs> to a new cpanfile.
+
+  # read MYMETA's prereqs and print cpanfile representation of it
+  my $meta = CPAN::Meta->load_file('MYMETA.json');
+  my $file = Module::CPANfile->from_prereqs($meta->prereqs);
+  print $file->to_sring;
+
+By default, it omits the phase where there're no modules
+registered. If you pass the argument of a true value, it will print
+them as well.
+
+=item save
+
+  $file->save('cpanfile');
+
+Saves the currently loaded prereqs as a new C<cpanfile> by calling
+C<to_string>. Beware B<this method will overwrite the existing
+cpanfile without any warning or backup>. Taking a backup or giving
+warnings to users is a caller's responsibility.
+
+  # Read MYMETA.json and creates a new cpanfile
+  my $meta = CPAN::Meta->load_file('MYMETA.json');
+  my $file = Module::CPANfile->from_prereqs($meta->prereqs);
+  $file->save('cpanfile');
+
 =item merge_meta
 
   $file->merge_meta('META.yml');
